%ifarch %{ix86}
%define        vpxtarget x86-linux-gcc
%else
%ifarch x86_64
%define        vpxtarget x86_64-linux-gcc
%else
%ifarch arm
%define        vpxtarget armv7-linux-gcc
%else
%define        vpxtarget generic-gnu
%endif
%endif
%endif

%define        majver %(echo %version | cut -d. -f 1-2)
%define        major  %(echo %version | cut -d. -f -1)

Name:          libvpx
Version:       1.15.0
Release:       1mamba
Summary:       VP8 Video Codec SDK
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://issues.webmproject.org/issues
Source0:       https://github.com/webmproject/libvpx/archive/v%{version}/libvpx-%{version}.tar.gz
Source1:       libvpx.pc
# from debian
Source2:       libvpx.ver
Patch0:        libvpx-0.9.0-no-explicit-dep-on-static-lib.patch
Patch1:        libvpx-0.9.5-I6266aba7.patch
License:       BSD
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libgcc
BuildRequires: libstdc++6-devel
## AUTOBUILDREQ-END
BuildRequires: doxygen
%if "%{stage1}" != "1"
BuildRequires: php
# TODO BuildRequires: %{_bindir}/php-cli
%endif
BuildRequires: yasm

%description
libvpx provides the VP8 SDK, which allows you to integrate your applications with the VP8 video codec, a high quality, royalty free, open source codec deployed on millions of computers and devices worldwide.

%package devel
Group:         Development/Libraries
Summary:       Static libraries and headers for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description devel
libvpx - VP8 Video Codec SDK.

This package contains static libraries and header files needed for development.

%package utils
Group:         Development/Tools
Summary:       Utility applications for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description utils
libvpx - VP8 Video Codec SDK.

The %{name}-tools package contains a selection of utilities and
tools for VP8, including a sample encoder and decoder.

%package docs
Group:         Documentation
Summary:       libvpx API documentation

%description docs
libvpx - VP8 Video Codec SDK.
This package contains libvpx API documentation.

%debug_package

%prep
%setup -q

%build
CROSS=%{_host}- \
./configure \
  --prefix=%{_prefix} \
  --libdir=%{_libdir} \
  --enable-pic \
  --disable-install-srcs \
%if "%{stage1}" !="1"
  --enable-install-docs \
%endif
  --enable-shared \
  --target=%{vpxtarget} \
  --enable-runtime-cpu-detect \
  --enable-shared \
  --enable-pic \
  --enable-vp8 \
  --enable-postproc \
  --enable-vp9 \
  --enable-vp9-highbitdepth \
  --enable-experimental
  
#  --enable-spatial-svc

%make

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall

# fix permissions
chmod 644 %{buildroot}%{_includedir}/vpx/*.h

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"


%files
%defattr(-,root,root)
%{_libdir}/libvpx.so.*
%doc AUTHORS LICENSE

%files devel
%defattr(-,root,root)
%dir %{_includedir}/vpx
%{_includedir}/vpx/*.h
%{_libdir}/libvpx.a
%{_libdir}/libvpx.so
%{_libdir}/pkgconfig/vpx.pc
%doc CHANGELOG README

%files utils
%defattr(-,root,root)
#%{_bindir}/vp8_scalable_patterns
#%{_bindir}/vp9_spatial_scalable_encoder
%{_bindir}/vpxdec
%{_bindir}/vpxenc

#%if "%{stage1}" !="1"
#%files docs
#%defattr(-,root,root)
##%doc docs/html/
#%endif

%changelog
* Sat Nov 02 2024 Automatic Build System <autodist@openmamba.org> 1.15.0-1mamba
- automatic version update by autodist

* Tue Jun 04 2024 Automatic Build System <autodist@openmamba.org> 1.14.1-1mamba
- automatic version update by autodist

* Sat Jan 20 2024 Automatic Build System <autodist@openmamba.org> 1.14.0-1mamba
- automatic version update by autodist

* Sat Sep 30 2023 Automatic Build System <autodist@mambasoft.it> 1.13.1-1mamba
- automatic version update by autodist

* Sat Feb 11 2023 Automatic Build System <autodist@mambasoft.it> 1.13.0-1mamba
- automatic version update by autodist

* Wed Jun 29 2022 Automatic Build System <autodist@mambasoft.it> 1.12.0-1mamba
- automatic version update by autodist

* Sat Oct 23 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 1.11.0-2mamba
- rebuilt with debug package

* Tue Oct 12 2021 Automatic Build System <autodist@mambasoft.it> 1.11.0-1mamba
- automatic version update by autodist

* Thu Mar 25 2021 Automatic Build System <autodist@mambasoft.it> 1.10.0-1mamba
- automatic version update by autodist

* Tue Aug 04 2020 Automatic Build System <autodist@mambasoft.it> 1.9.0-1mamba
- automatic version update by autodist

* Mon Dec 23 2019 Automatic Build System <autodist@mambasoft.it> 1.8.2-1mamba
- automatic version update by autodist

* Wed Jul 17 2019 Automatic Build System <autodist@mambasoft.it> 1.8.1-1mamba
- automatic version update by autodist

* Thu Apr 25 2019 Automatic Build System <autodist@mambasoft.it> 1.8.0-1mamba
- automatic version update by autodist

* Wed Mar 21 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.0-1mamba
- update to 1.7.0

* Sun Jan 15 2017 Automatic Build System <autodist@mambasoft.it> 1.6.1-1mamba
- automatic version update by autodist

* Sun Dec 11 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.0-2mamba
- added many configure options for chromium

* Fri Aug 05 2016 Automatic Build System <autodist@mambasoft.it> 1.6.0-1mamba
- automatic version update by autodist

* Thu Nov 12 2015 Automatic Build System <autodist@mambasoft.it> 1.5.0-1mamba
- automatic version update by autodist

* Thu Apr 30 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.0-1mamba
- update to 1.4.0

* Sun Jan 12 2014 Automatic Build System <autodist@mambasoft.it> 1.3.0-1mamba
- automatic version update by autodist

* Thu Oct 17 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.0-2mamba
- fix permissions of header files

* Wed Sep 04 2013 Automatic Build System <autodist@mambasoft.it> 1.2.0-1mamba
- automatic version update by autodist

* Wed Nov 14 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1.0-1mamba
- update to 1.1.0

* Tue Aug 02 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.6-3mamba
- rebuilt in devel

* Fri Mar 18 2011 gil <puntogil@libero.it> 0.9.6-2mamba
- fix broken header files

* Fri Mar 18 2011 gil <puntogil@libero.it> 0.9.6-1mamba
- update to 0.9.6

* Fri Feb 25 2011 gil <puntogil@libero.it> 0.9.5-1mamba
- package created by autospec
